==> haskell-arch-web-0.3.2-7-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-arch-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arch-web
version:              0.3.2
visibility:           public
id:                   arch-web-0.3.2-H4ZmtaZsdGrDAn2HibVuRi
key:                  arch-web-0.3.2-H4ZmtaZsdGrDAn2HibVuRi
license:              MIT
copyright:            Copyright (c) berberman 2020-2025
maintainer:           berberman <berberman@yandex.com>
author:               berberman
stability:            alpha
homepage:             https://github.com/berberman/arch-web
synopsis:             Arch Linux official and AUR web interface binding
description:
    Arch Linux official and AUR web interface binding.
    See README for details.

category:             Web
abi:                  9f35e930f13623fab3edbd8faf71de7e
exposed:              True
exposed-modules:
    Web.ArchLinux Web.ArchLinux.API Web.ArchLinux.Types
    Web.ArchLinux.Types.Lens

hidden-modules:
    Web.ArchLinux.Internal.KnownSPDXLoader Web.ArchLinux.Types.API

import-dirs:          /usr/lib/ghc-9.4.8/site-local/arch-web-0.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/arch-web-0.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/arch-web-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arch-web
hs-libraries:         HSarch-web-0.3.2-H4ZmtaZsdGrDAn2HibVuRi
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    deriving-aeson-0.2.10-DyRVDG7qcDqG84zj0EJ3Ue directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    http-client-0.7.19-LiXl0zXhncYKUDAcqgcwk8
    http-client-tls-0.3.6.4-8Rtb2QgRnuG7Z2EdKrVOdn
    http-types-0.12.4-Kfgn5nq0Uw5JM2IxBj4ZY1
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR mtl-2.2.2
    servant-0.20.3.0-GOIaCeayVrDJ22GgZs5cgj
    servant-client-0.20.3.0-5s7zGzfAItOB4ZzFrtUduz
    servant-client-core-0.20.3.0-ElEnQUK02Oe3ydbQ9eDBFI
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-arch-web/html/arch-web.haddock
haddock-html:         /usr/share/doc/haskell-arch-web/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-arch-web-0.3.2-37-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-arch-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arch-web
version:              0.3.2
visibility:           public
id:                   arch-web-0.3.2-1qkRN9pTYXYJR7lRHTWdOb
key:                  arch-web-0.3.2-1qkRN9pTYXYJR7lRHTWdOb
license:              MIT
copyright:            Copyright (c) berberman 2020-2025
maintainer:           berberman <berberman@yandex.com>
author:               berberman
stability:            alpha
homepage:             https://github.com/berberman/arch-web
synopsis:             Arch Linux official and AUR web interface binding
description:
    Arch Linux official and AUR web interface binding.
    See README for details.

category:             Web
abi:                  3d3ba52ba6bed0802f718c22652782da
exposed:              True
exposed-modules:
    Web.ArchLinux Web.ArchLinux.API Web.ArchLinux.Types
    Web.ArchLinux.Types.Lens

hidden-modules:
    Web.ArchLinux.Internal.KnownSPDXLoader Web.ArchLinux.Types.API

import-dirs:          /usr/lib/ghc-9.4.8/site-local/arch-web-0.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/arch-web-0.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/arch-web-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arch-web
hs-libraries:         HSarch-web-0.3.2-1qkRN9pTYXYJR7lRHTWdOb
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    deriving-aeson-0.2.10-3To9O5BQBBV76NEn2Ddj05 directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    http-client-0.7.19-Iyp8kyAVyHs5ic3dfNFLTs
    http-client-tls-0.3.6.4-Fuw6mDzbeZhIZH9nOSD8AM
    http-types-0.12.4-3Rkn4NOOYhzvBVdRap5Ii
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb mtl-2.2.2
    servant-0.20.3.0-5yfHPrFnFIjC5udvdKPgHT
    servant-client-0.20.3.0-FQJcxzQHMgZ43pa5N5fjmb
    servant-client-core-0.20.3.0-168OqtrGYus1cDAOzzAo5H
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-arch-web/html/arch-web.haddock
haddock-html:         /usr/share/doc/haskell-arch-web/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
